Documentation
¶
Index ¶
Constants ¶
const ( DankDir = ".dank" // DankDir is the directory where dank-mcp stores its data. CacheDir = "cache" // CacheDir is the directory under DankDir where dank-mcp stores its cache files. )
Variables ¶
This section is empty.
Functions ¶
func CheckCacheFile ¶
ChaekCacheFile checks DankDir/cache for a file. Returns its bytes and error, if any. If the file is not found, it returns an error. If the file is older than maxAge, it returns an error.
func GetDankCacheDir ¶
func GetDankCacheDir() string
GetDankCacheDir returns the path to the CacheDir directory.
func GetDankCachePathname ¶
GetDankCachePathname returns the path to the given filename within the CacheDir.
func MakeCacheFile ¶
MakeCacheFile creates a cache file in the DankDir/cache directory and returns its handles. Returns nil with any error.
func SetDankRoot ¶
func SetDankRoot(root string)
SetDankRoot sets the root directory for dank-mcp data.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.